import { XhsClient as XhsClientBase } from '@kevisual/xhs-core';

export const getSign = async (uri: string, data: any, a1: string, web_session?: string) => {
  const signs = await fetch('http://light.xiongxiao.me:5006/sign', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
    },
    body: JSON.stringify({
      uri,
      data,
      a1,
      web_session: web_session,
    }),
  }).then((res) => res.json());
  return signs;
};
type XhsOptions = {
  cookie?: string;
};
export class XhsClient extends XhsClientBase {
  constructor(opts: XhsOptions) {
    super(opts as any);
  }
  /**
   *  获取未读消息
   * @returns
   */
  async getUnread(): Promise<UnreadCount> {
    const url = '/api/sns/web/unread_count';
    const response = await this.get(url);
    return response;
  }
  async sign(uri: string, data: any, config: any) {
    let header = config?.header || {};
    const cookieDist = this.getCookieMap();
    const web_session = cookieDist['web_session'];
    const a1 = cookieDist['a1'];
    const res = await getSign(uri, data, a1, web_session);
    header['x-s'] = res['x-s'];
    header['x-t'] = res['x-t'];
    config.header = header;
    return config;
  }
  async getNoteById(noteId: string, xsecToken?: string) {
    const data = {
      source_note_id: noteId,
      image_scenes: ['CRD_WM_WEBP'],
    };
    const uri = '/api/sns/web/v1/feed';

    try {
      const response = await this.post(uri, data, { sign: this.sign.bind(this) });
      return response['items'][0]['node_card'];
    } catch (error) {
      console.log(error);
    }
  }
}

type UnreadCount = {
  unread_count: number;
  likes: number;
  connections: number;
  mentions: number;
};
